@@ -268,14 +268,14 @@ def extract_ts(data_path: str, mask_path: str, label: Union[int, float, int],
         logging.warning(f"Radiomics extracting error: {e}, \ndata_path: {data_path}, \nmask_path: {mask_path}")
 
 
-def extract(dataset: Dataset, result_dir: str, config_path: str,
+def extract(data_dir: str, result_dir: str, config_path: str,
             processes: int = 2, cloud_run: bool = False) -> RadiomicsFeatureExtractor:
     """
 
     Parameters
     ----------
-    dataset : raymics.dataset.Dataset
-        instance of raymics.dataset.Dataset
+    data_dir : str
+        Directory of the raw dataset.
 
     result_dir : str
         提取到的radiomics特征文件存放文件夹
@@ -292,6 +292,8 @@ def extract(dataset: Dataset, result_dir: str, config_path: str,
     """
     assert os.path.exists(config_path), f"Config yaml file not found."
 
+    dataset = LabeledDataset(root_dir=data_dir)
+
     if not os.path.exists(result_dir):
         os.makedirs(result_dir)
 
@@ -392,9 +394,7 @@ if __name__ == "__main__":
 
     args = parser.parse_args()
 
-    dataset = LabeledDataset(root_dir=args.data_dir)
-
-    extract(dataset=dataset,
+    extract(data_dir=args.data_dir,
             config_path=args.config_path,
             result_dir=args.result_dir,
             cloud_run=args.cloud_run,
